@@ -47,11 +47,7 @@ bool AbstractDb::close()
     if (deny)
         return false;
 
-    bool open = isOpen();
-    if (open)
-        flushWal();
-
-    bool res = !open || closeQuiet();
+    bool res = !isOpen() || closeQuiet();
     manuallyLoadedExtensions.clear();
     if (res)
         emit disconnected();
@@ -706,8 +702,7 @@ void AbstractDb::asyncQueryFinished(AsyncQueryRunner *runner)
 
 void AbstractDb::appIsAboutToQuit()
 {
-    if (isOpen())
-        flushWal();
+    closeInternal();
 }
 
 QString AbstractDb::attach(Db* otherDb, bool silent)
@@ -958,20 +953,6 @@ void AbstractDb::registerFunction(const AbstractDb::RegisteredFunction& function
         qCritical() << "Could not register SQL function:" << function.name << function.argCount << function.type;
 }
 
-void AbstractDb::flushWal()
-{
-    if (flushWalInternal())
-    {
-        if (exec("PRAGMA journal_mode")->getSingleCell().toString() == "wal")
-        {
-            exec("PRAGMA journal_mode = delete;", Flag::ZERO_TIMEOUT);
-            exec("PRAGMA journal_mode = wal;", Flag::ZERO_TIMEOUT);
-        }
-    }
-    else
-        notifyWarn(tr("Failed to make full WAL checkpoint on database '%1'. Error returned from SQLite engine: %2").arg(name, getErrorTextInternal()));
-}
-
 int qHash(const AbstractDb::RegisteredFunction& fn)
 {
     return qHash(fn.name) ^ fn.argCount ^ fn.type;
